@@ -1,6 +1,7 @@
 use crypto_market_type::MarketType;
+use crypto_msg_type::MessageType;
 
-use crate::{FundingRateMsg, MessageType, Order, OrderBookMsg, TradeMsg, TradeSide};
+use crate::{FundingRateMsg, Order, OrderBookMsg, TradeMsg, TradeSide};
 
 use super::super::utils::calc_quantity_and_volume;
 use serde::{Deserialize, Serialize};
