@@ -1,7 +1,8 @@
 use crypto_market_type::MarketType;
+use crypto_msg_type::MessageType;
 
 use super::messages::WebsocketMsg;
-use crate::{MessageType, Order, OrderBookMsg, TradeMsg, TradeSide};
+use crate::{Order, OrderBookMsg, TradeMsg, TradeSide};
 use serde::{Deserialize, Serialize};
 use serde_json::{Result, Value};
 use std::collections::HashMap;
