@@ -148,7 +148,12 @@ mod funding_rate {
         assert_eq!(funding_rates.len(), 1);
 
         for rate in funding_rates.iter() {
-            crate::utils::check_funding_rate_fields("binance", MarketType::InverseSwap, rate);
+            crate::utils::check_funding_rate_fields(
+                "binance",
+                MarketType::InverseSwap,
+                rate,
+                raw_msg,
+            );
         }
 
         assert_eq!(funding_rates[0].pair, "BTC/USD".to_string());
@@ -162,7 +167,12 @@ mod funding_rate {
         assert_eq!(funding_rates.len(), 2);
 
         for rate in funding_rates.iter() {
-            crate::utils::check_funding_rate_fields("binance", MarketType::InverseSwap, rate);
+            crate::utils::check_funding_rate_fields(
+                "binance",
+                MarketType::InverseSwap,
+                rate,
+                raw_msg,
+            );
         }
 
         assert_eq!(funding_rates[0].pair, "BTC/USD".to_string());
@@ -183,7 +193,12 @@ mod funding_rate {
         assert_eq!(funding_rates.len(), 1);
 
         for rate in funding_rates.iter() {
-            crate::utils::check_funding_rate_fields("binance", MarketType::LinearSwap, rate);
+            crate::utils::check_funding_rate_fields(
+                "binance",
+                MarketType::LinearSwap,
+                rate,
+                raw_msg,
+            );
         }
 
         assert_eq!(funding_rates[0].pair, "BTC/USDT".to_string());
@@ -197,7 +212,12 @@ mod funding_rate {
         assert_eq!(funding_rates.len(), 2);
 
         for rate in funding_rates.iter() {
-            crate::utils::check_funding_rate_fields("binance", MarketType::LinearSwap, rate);
+            crate::utils::check_funding_rate_fields(
+                "binance",
+                MarketType::LinearSwap,
+                rate,
+                raw_msg,
+            );
         }
 
         assert_eq!(funding_rates[0].pair, "BTC/USDT".to_string());
