@@ -197,7 +197,7 @@ mod funding_rate {
         assert_eq!(funding_rates.len(), 1);
 
         for rate in funding_rates.iter() {
-            crate::utils::check_funding_rate_fields("okex", MarketType::InverseSwap, rate);
+            crate::utils::check_funding_rate_fields("okex", MarketType::InverseSwap, rate, raw_msg);
         }
 
         assert_eq!(funding_rates[0].pair, "BTC/USD".to_string());
@@ -214,7 +214,7 @@ mod funding_rate {
         assert_eq!(funding_rates.len(), 1);
 
         for rate in funding_rates.iter() {
-            crate::utils::check_funding_rate_fields("okex", MarketType::LinearSwap, rate);
+            crate::utils::check_funding_rate_fields("okex", MarketType::LinearSwap, rate, raw_msg);
         }
 
         assert_eq!(funding_rates[0].pair, "BTC/USDT".to_string());
